@@ -26,7 +26,7 @@ from niworkflows.interfaces.utility import KeySelect
 from niworkflows.utils.misc import fix_multi_T1w_source_name, add_suffix
 from niworkflows.anat.ants import init_brain_extraction_wf, init_n4_only_wf
 from ..utils.bids import get_outputnode_spec
-from ..utils.misc import apply_lut as _apply_bids_lut
+from ..utils.misc import apply_lut as _apply_bids_lut, fs_isRunning as _fs_isRunning
 from .norm import init_anat_norm_wf
 from .outputs import init_anat_reports_wf, init_anat_derivatives_wf
 from .surfaces import init_surface_recon_wf
@@ -35,6 +35,7 @@ LOGGER = logging.getLogger('nipype.workflow')
 
 
 def init_anat_preproc_wf(
+        *,
         bids_root,
         freesurfer,
         hires,
@@ -128,10 +129,14 @@ def init_anat_preproc_wf(
         List of T1-weighted structural images
     t2w
         List of T2-weighted structural images
+    roi
+        A mask to exclude regions during standardization
     flair
         List of FLAIR images
     subjects_dir
         FreeSurfer SUBJECTS_DIR
+    subject_id
+        FreeSurfer subject ID
 
     Outputs
     -------
@@ -224,8 +229,7 @@ Anatomical preprocessing was reused from previously existing derivative objects.
         for field, value in existing_derivatives.items():
             setattr(outputnode.inputs, field, value)
 
-        anat_reports_wf.inputs.inputnode.source_file = fix_multi_T1w_source_name(
-            [existing_derivatives['t1w_preproc']])
+        anat_reports_wf.inputs.inputnode.source_file = [existing_derivatives['t1w_preproc']]
 
         stdselect = pe.Node(KeySelect(
             fields=['std_preproc', 'std_mask'], keys=templates),
@@ -366,8 +370,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
 
     # Connect reportlets
     workflow.connect([
-        (inputnode, anat_reports_wf, [
-            (('t1w', fix_multi_T1w_source_name), 'inputnode.source_file')]),
+        (inputnode, anat_reports_wf, [('t1w', 'inputnode.source_file')]),
         (outputnode, anat_reports_wf, [
             ('std_preproc', 'inputnode.std_t1w'),
             ('std_mask', 'inputnode.std_mask'),
@@ -384,6 +387,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         freesurfer=freesurfer,
         num_t1w=num_t1w,
         output_dir=output_dir,
+        spaces=spaces,
     )
 
     workflow.connect([
@@ -391,58 +395,59 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
         (anat_template_wf, anat_derivatives_wf, [
             ('outputnode.t1w_valid_list', 'inputnode.source_files')]),
         (anat_norm_wf, anat_derivatives_wf, [
-            ('poutputnode.template', 'inputnode.template'),
-            ('poutputnode.anat2std_xfm', 'inputnode.anat2std_xfm'),
-            ('poutputnode.std2anat_xfm', 'inputnode.std2anat_xfm')
+            ('outputnode.template', 'inputnode.template'),
+            ('outputnode.anat2std_xfm', 'inputnode.anat2std_xfm'),
+            ('outputnode.std2anat_xfm', 'inputnode.std2anat_xfm')
         ]),
         (outputnode, anat_derivatives_wf, [
-            ('std_preproc', 'inputnode.std_t1w'),
             ('t1w_ref_xfms', 'inputnode.t1w_ref_xfms'),
             ('t1w_preproc', 'inputnode.t1w_preproc'),
             ('t1w_mask', 'inputnode.t1w_mask'),
             ('t1w_dseg', 'inputnode.t1w_dseg'),
             ('t1w_tpms', 'inputnode.t1w_tpms'),
-            ('std_mask', 'inputnode.std_mask'),
-            ('std_dseg', 'inputnode.std_dseg'),
-            ('std_tpms', 'inputnode.std_tpms'),
         ]),
     ])
 
-    if not freesurfer:  # Flag --fs-no-reconall is set - return
-        # Brain tissue segmentation - FAST produces: 0 (bg), 1 (wm), 2 (csf), 3 (gm)
-        t1w_dseg = pe.Node(fsl.FAST(segments=True, no_bias=True, probability_maps=True),
-                           name='t1w_dseg', mem_gb=3)
-        lut_t1w_dseg.inputs.lut = (0, 3, 1, 2)  # Maps: 0 -> 0, 3 -> 1, 1 -> 2, 2 -> 3.
-        fast2bids = pe.Node(niu.Function(function=_probseg_fast2bids), name="fast2bids",
-                            run_without_submitting=True)
+    # Brain tissue segmentation - FAST produces: 0 (bg), 1 (wm), 2 (csf), 3 (gm)
+    t1w_dseg = pe.Node(fsl.FAST(segments=True, no_bias=True, probability_maps=True),
+                       name='t1w_dseg', mem_gb=3)
+    lut_t1w_dseg.inputs.lut = (0, 3, 1, 2)  # Maps: 0 -> 0, 3 -> 1, 1 -> 2, 2 -> 3.
+    fast2bids = pe.Node(niu.Function(function=_probseg_fast2bids), name="fast2bids",
+                        run_without_submitting=True)
+    workflow.connect([
+        (buffernode, t1w_dseg, [('t1w_brain', 'in_files')]),
+        (t1w_dseg, lut_t1w_dseg, [('partial_volume_map', 'in_dseg')]),
+        (t1w_dseg, fast2bids, [('partial_volume_files', 'inlist')]),
+        (fast2bids, anat_norm_wf, [('out', 'inputnode.moving_tpms')]),
+        (fast2bids, outputnode, [('out', 't1w_tpms')]),
+    ])
 
+    if not freesurfer:  # Flag --fs-no-reconall is set - return
         workflow.connect([
             (brain_extraction_wf, buffernode, [
                 (('outputnode.out_file', _pop), 't1w_brain'),
                 ('outputnode.out_mask', 't1w_mask')]),
-            (buffernode, t1w_dseg, [('t1w_brain', 'in_files')]),
-            (t1w_dseg, lut_t1w_dseg, [('tissue_class_map', 'in_dseg')]),
-            (t1w_dseg, fast2bids, [('probability_maps', 'inlist')]),
-            (fast2bids, anat_norm_wf, [('out', 'inputnode.moving_tpms')]),
-            (fast2bids, outputnode, [('out', 't1w_tpms')]),
         ])
         return workflow
 
-    # Map FS' aseg labels onto three-tissue segmentation
-    lut_t1w_dseg.inputs.lut = _aseg_to_three()
-    split_seg = pe.Node(niu.Function(function=_split_segments),
-                        name='split_seg')
+    # check for older IsRunning files and remove accordingly
+    fs_isrunning = pe.Node(niu.Function(function=_fs_isRunning),
+                           overwrite=True, name='fs_isrunning')
+    fs_isrunning.inputs.logger = LOGGER
 
     # 5. Surface reconstruction (--fs-no-reconall not set)
     surface_recon_wf = init_surface_recon_wf(name='surface_recon_wf',
                                              omp_nthreads=omp_nthreads, hires=hires)
     applyrefined = pe.Node(fsl.ApplyMask(), name='applyrefined')
     workflow.connect([
+        (inputnode, fs_isrunning, [
+            ('subjects_dir', 'subjects_dir'),
+            ('subject_id', 'subject_id')]),
         (inputnode, surface_recon_wf, [
             ('t2w', 'inputnode.t2w'),
             ('flair', 'inputnode.flair'),
-            ('subjects_dir', 'inputnode.subjects_dir'),
             ('subject_id', 'inputnode.subject_id')]),
+        (fs_isrunning, surface_recon_wf, [('out', 'inputnode.subjects_dir')]),
         (anat_validate, surface_recon_wf, [('out_file', 'inputnode.t1w')]),
         (brain_extraction_wf, surface_recon_wf, [
             (('outputnode.out_file', _pop), 'inputnode.skullstripped_t1'),
@@ -452,12 +457,6 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             (('outputnode.bias_corrected', _pop), 'in_file')]),
         (surface_recon_wf, applyrefined, [
             ('outputnode.out_brainmask', 'mask_file')]),
-        (surface_recon_wf, lut_t1w_dseg, [
-            ('outputnode.out_aseg', 'in_dseg')]),
-        (lut_t1w_dseg, split_seg, [('out', 'in_file')]),
-        (split_seg, anat_norm_wf, [
-            ('out', 'inputnode.moving_tpms')]),
-        (split_seg, outputnode, [('out', 't1w_tpms')]),
         (surface_recon_wf, outputnode, [
             ('outputnode.subjects_dir', 'subjects_dir'),
             ('outputnode.subject_id', 'subject_id'),
@@ -486,7 +485,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
     return workflow
 
 
-def init_anat_template_wf(longitudinal, omp_nthreads, num_t1w, name='anat_template_wf'):
+def init_anat_template_wf(*, longitudinal, omp_nthreads, num_t1w, name='anat_template_wf'):
     """
     Generate a canonically-oriented, structural average from all input T1w images.
 
